from django.conf import settings  # noqa
from appconf import AppConf


class DjangoRemoteAuthLdapAppConf(AppConf):
    CHECK_DOMAIN = True
    STRIP_DOMAIN = True
    DOMAINS = []
    HEADER = 'REMOTE_USER'

    class Meta:
        prefix = 'DRAL'



from django.contrib.auth.backends import RemoteUserBackend

from django_auth_ldap.backend import LDAPBackend, _LDAPUser
from django_remote_auth_ldap.conf import settings


class RemoteUserLDAPBackend(LDAPBackend):
    # unforgivable megahax to avoid reimplementing RemoteUserMiddleware
    __class__ = RemoteUserBackend

    def authenticate(self, request, remote_user):
        if not self.correct_domain(remote_user):
            return None

        username = self.clean_username(remote_user)
        ldap_user = RemoteLDAPUser(self, username=username)
        user = ldap_user.authenticate('')

        return user

    def correct_domain(self, username):
        if not settings.DRAL_CHECK_DOMAIN:
            return True
        if '\\' not in username:
            return False
        (dom, username) = username.split('\\', 1)
        return dom.lower() in settings.DRAL_DOMAINS

    def clean_username(self, username):
        if not settings.DRAL_STRIP_DOMAIN:
            return username
        if '\\' not in username:
            return username
        (dom, username) = username.split('\\', 1)
        return username


class RemoteLDAPUser(_LDAPUser):
    def _authenticate_user_dn(self, password):
        if self.dn is None:
            msg = "Failed to map the username to a DN."
            raise self.AuthenticationFailed(msg)



from django.contrib.auth import middleware
from django_remote_auth_ldap.conf import settings


class RemoteUserMiddleware(middleware.RemoteUserMiddleware):
    @property
    def header(self):
        return settings.DRAL_HEADER



from setuptools import setup, find_packages
import os

here = os.path.abspath(os.path.dirname(__file__))
README = open(os.path.join(here, 'README.md')).read()


version = '1.0.0'

install_requires = [
    'django-auth-ldap',
    'django-appconf'
]

setup(
    name='django-remote-auth-ldap',
    version=version,
    description="REMOTE_USER authentication using LDAP",
    long_description=README,
    classifiers=[
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Framework :: Django',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Topic :: Internet :: WWW/HTTP',
    ],
    keywords='',
    author='Austin Morton',
    author_email='amorton@juvsoft.com',
    url='https://github.com/apmorton/django-remote-auth-ldap',
    license='MIT',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    zip_safe=False,
    install_requires=install_requires,
    test_suite='nose.collector'
)
